==> dokuwiki_0.0.20080505.orig.tar.gz: dokuwiki-2008-05-05/lib/plugins/acl/lang/ro/lang.php <==
<?php
/**
 * Romanian language file
 *
 * @author Sergiu Baltariu <s_baltariu@yahoo.com>
 * @author s_baltariu@yahoo.com
 */
$lang['admin_acl']             = 'Managementul Listei de Control a Accesului';
$lang['acl_group']             = 'Grup';
$lang['acl_user']              = 'Utilizator';
$lang['acl_perms']             = 'Autorizare pentru';
$lang['page']                  = 'Pagina';
$lang['namespace']             = 'Spaţiu de nume';
$lang['p_user_id']             = 'Utilizatorul <b class="acluser">%s</b> are următoarele autorizaţii pe pagină <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_user_ns']             = 'Utilizatorul <b class="acluser">%s</b> are următoarele autorizaţii pe spaţiul de nume <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_group_id']            = 'Membrii grupului <b class="aclgroup">%s</b> au următoarele autorizaţii pe pagină <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_group_ns']            = 'Membrii grupului <b class="aclgroup">%s</b> au următoarele autorizaţii pe spaţiul de nume <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_choose_id']           = '<b>Introduceţi un utilizator sau un grup</b> în formularul de mai sus pentru a vizualiza sau edita autorizaţiile paginii <b class="aclpage">%s</b>.';
$lang['p_choose_ns']           = '<b>Introduceţi un utilizator sau un grup</b> în formularul de mai sus pentru a vizualiza sau edita autorizaţiile spaţiului de nume <b class="aclns">%s</b>.';
$lang['p_inherited']           = 'Notă: Aceste autorizaţii nu au fost setate explicit ci au fost moştenite de la alte grupuri sau spaţii de nume superioare ierarhic.';
$lang['p_isadmin']             = 'Notă: Grupul sau utilizatorul selectat are intotdeauna toate autorizatiile întrucât este configurat ca superutilizator.';
$lang['current']               = 'Reguli ACL actuale';
$lang['where']                 = 'Pagină/Spaţiu de nume';
$lang['who']                   = 'Utilizator/Grup';
$lang['perm']                  = 'Autorizaţii';
$lang['acl_perm0']             = 'Nici una';
$lang['acl_perm1']             = 'Citire';
$lang['acl_perm2']             = 'Editare';
$lang['acl_perm4']             = 'Creare';
$lang['acl_perm8']             = 'Încărcare';
$lang['acl_perm16']            = 'Ştergere';
$lang['acl_new']               = 'Adaugă intrare nouă';
$lang['acl_mod']               = 'Modifică intrare';

==> dokuwiki_0.0.20090214b.orig.tar.gz: dokuwiki-2009-02-14/lib/plugins/acl/lang/ro/lang.php <==
<?php
/**
 * Romanian language file
 *
 * @author Sergiu Baltariu <s_baltariu@yahoo.com>
 * @author s_baltariu@yahoo.com
 * @author Emanuel-Emeric Andrasi <n30@mandrivausers.ro>
 */
$lang['admin_acl']             = 'Managementul Listei de Control a Accesului';
$lang['acl_group']             = 'Grup';
$lang['acl_user']              = 'Utilizator';
$lang['acl_perms']             = 'Autorizare pentru';
$lang['page']                  = 'Pagina';
$lang['namespace']             = 'Spaţiu de nume';
$lang['btn_select']            = 'Selectează';
$lang['p_user_id']             = 'Utilizatorul <b class="acluser">%s</b> are următoarele autorizaţii pe pagină <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_user_ns']             = 'Utilizatorul <b class="acluser">%s</b> are următoarele autorizaţii pe spaţiul de nume <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_group_id']            = 'Membrii grupului <b class="aclgroup">%s</b> au următoarele autorizaţii pe pagină <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_group_ns']            = 'Membrii grupului <b class="aclgroup">%s</b> au următoarele autorizaţii pe spaţiul de nume <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_choose_id']           = '<b>Introduceţi un utilizator sau un grup</b> în formularul de mai sus pentru a vizualiza sau edita autorizaţiile paginii <b class="aclpage">%s</b>.';
$lang['p_choose_ns']           = '<b>Introduceţi un utilizator sau un grup</b> în formularul de mai sus pentru a vizualiza sau edita autorizaţiile spaţiului de nume <b class="aclns">%s</b>.';
$lang['p_inherited']           = 'Notă: Aceste autorizaţii nu au fost setate explicit ci au fost moştenite de la alte grupuri sau spaţii de nume superioare ierarhic.';
$lang['p_isadmin']             = 'Notă: Grupul sau utilizatorul selectat are intotdeauna toate autorizatiile întrucât este configurat ca superutilizator.';
$lang['p_include']             = 'Permisiunile superioare le includ pe cele inferioare. Permisiunile de Creare, Upload şi Ştergere se aplică doar numelor de spaţiu, nu paginilor.';
$lang['current']               = 'Reguli ACL actuale';
$lang['where']                 = 'Pagină/Spaţiu de nume';
$lang['who']                   = 'Utilizator/Grup';
$lang['perm']                  = 'Autorizaţii';
$lang['acl_perm0']             = 'Nici una';
$lang['acl_perm1']             = 'Citire';
$lang['acl_perm2']             = 'Editare';
$lang['acl_perm4']             = 'Creare';
$lang['acl_perm8']             = 'Încărcare';
$lang['acl_perm16']            = 'Ştergere';
$lang['acl_new']               = 'Adaugă intrare nouă';
$lang['acl_mod']               = 'Modifică intrare';
